@@ -23,8 +23,8 @@ Supported input channels:
 
 Created on 24 Jul 2024
 
-:author: semuadmin
-:copyright: SEMU Consulting © 2022
+:author: semuadmin (Steve Smith)
+:copyright: semuadmin © 2022
 :license: BSD 3-Clause
 """
 
@@ -37,8 +37,6 @@ from time import sleep
 from types import FunctionType
 
 from pynmeagps import SocketWrapper
-from pysbf2 import SBFReader
-from pyubx2 import ERR_LOG, SETPOLL, UBXReader
 from pyubxutils.ubxsimulator import UBXSimulator
 from serial import Serial, SerialException
 
@@ -64,16 +62,20 @@ from pygnssutils.globals import (
     INPUT_NTRIP_RTCM,
     INPUT_NTRIP_SPARTN,
     INPUT_SERIAL,
+    MAXCONNECTION,
+    NTRIP2,
     OUTPUT_FILE,
     OUTPUT_HANDLER,
     OUTPUT_NONE,
     OUTPUT_SERIAL,
     OUTPUT_SOCKET,
+    OUTPUT_SOCKET_TLS,
     OUTPUT_TEXT_FILE,
     UBXSIMULATOR,
 )
 from pygnssutils.gnssmqttclient import GNSSMQTTClient
 from pygnssutils.gnssntripclient import GNSSNTRIPClient
+from pygnssutils.gnssreader import ERR_LOG, SETPOLL, GNSSReader
 from pygnssutils.gnssstreamer import GNSSStreamer
 from pygnssutils.helpers import parse_url, set_common_args
 from pygnssutils.socket_server import runserver
@@ -202,7 +204,7 @@ def _setup_input_stream(app: object, datatype: str, **kwargs) -> object:
         """
 
         try:
-            ubr = UBXReader(stream, msgmode=SETPOLL, quitonerror=ERR_LOG)
+            ubr = GNSSReader(stream, msgmode=SETPOLL, quitonerror=ERR_LOG)
             for raw, _ in ubr:
                 if raw is not None:
                     output.put(raw)
@@ -268,14 +270,15 @@ def _setup_output(**kwargs):
         with Serial(port, int(baud), timeout=3) as output:
             kwargs["output"] = output
             _setup_datastream(**kwargs)
-    elif cliout == OUTPUT_SOCKET:
+    elif cliout in (OUTPUT_SOCKET, OUTPUT_SOCKET_TLS):
         host, port = output.split(":")
+        tls = cliout == OUTPUT_SOCKET_TLS
         output = Queue()
         # socket server runs as background thread, piping
         # output from gnssstreamer via a message queue
         Thread(
             target=runserver,
-            args=(host, int(port), output),
+            args=(host, int(port), output, 0, MAXCONNECTION, tls, NTRIP2),
             daemon=True,
         ).start()
         kwargs["output"] = output
@@ -476,9 +479,9 @@ def main():
     ap.add_argument(
         "--protfilter",
         required=False,
-        help="1 = NMEA, 2 = UBX, 4 = RTCM3, 8 = SBF (can be OR'd; UBX and SBF are mutually exclusive, UBX takes precedence over SBF)",
+        help="1 = NMEA, 2 = UBX, 4 = RTCM3, 8 = SBF, 16 = QGC (can be OR'd)",
         type=int,
-        default=7,
+        default=31,
     )
     ap.add_argument(
         "--msgfilter",
@@ -505,6 +508,7 @@ def main():
             f"{OUTPUT_FILE} = binary file, "
             f"{OUTPUT_SERIAL} = serial port, "
             f"{OUTPUT_SOCKET} = TCP socket server, "
+            f"{OUTPUT_SOCKET_TLS} = TCP socket server with TLS, "
             f"{OUTPUT_HANDLER} = evaluable Python expression, "
             f"{OUTPUT_TEXT_FILE} = text file"
         ),
@@ -514,6 +518,7 @@ def main():
             OUTPUT_FILE,
             OUTPUT_SERIAL,
             OUTPUT_SOCKET,
+            OUTPUT_SOCKET_TLS,
             OUTPUT_HANDLER,
             OUTPUT_TEXT_FILE,
         ],
@@ -527,7 +532,8 @@ def main():
             f"If clioutput = {OUTPUT_FILE} or {OUTPUT_TEXT_FILE}, format = file name "
             "(e.g. '/home/myuser/ubxdata.ubx'); "
             f"If clioutput = {OUTPUT_SERIAL}, format = port@baudrate (e.g. '/dev/tty.ACM0@38400'); "
-            f"If clioutput = {OUTPUT_SOCKET}, format = hostip:port (e.g. '0.0.0.0:50010'); "
+            f"If clioutput = {OUTPUT_SOCKET} or {OUTPUT_SOCKET_TLS}, "
+            "format = hostip:port (e.g. '0.0.0.0:50010'); "
             f"If clioutput = {OUTPUT_HANDLER}, format = evaluable Python expression. "
             "NB: gnssstreamer will have exclusive use of any serial or server port."
         ),
